@@ -113,7 +113,7 @@ private:
     void handleEditLocallyFromOptions();
 
     AccountManager::AccountsRestoreResult restoreLegacyAccount();
-    bool setupConfigFolderFromLegacyLocation(const QString &legacyLocation) const;
+    void setupConfigFile();
     void setupAccountsAndFolders();
 
     /**
