@@ -28,139 +28,41 @@ namespace OCC {
 
 Q_LOGGING_CATEGORY(lcEditLocallyJob, "nextcloud.gui.editlocallyjob", QtInfoMsg)
 
-EditLocallyJob::EditLocallyJob(const QString &userId,
-                                       const QString &relPath,
-                                       const QString &token,
-                                       QObject *parent)
+EditLocallyJob::EditLocallyJob(const AccountStatePtr &accountState,
+                               const QString &relPath,
+                               QObject *parent)
     : QObject{parent}
-    , _userId(userId)
+    , _accountState(accountState)
     , _relPath(relPath)
-    , _token(token)
 {
     connect(this, &EditLocallyJob::callShowError, this, &EditLocallyJob::showError, Qt::QueuedConnection);
 }
 
 void EditLocallyJob::startSetup()
 {
-    if (_token.isEmpty() || _relPath.isEmpty() || _userId.isEmpty()) {
+    if (_relPath.isEmpty() || !_accountState) {
         qCWarning(lcEditLocallyJob) << "Could not start setup."
-                                        << "token:" << _token
-                                        << "relPath:" << _relPath
-                                        << "userId" << _userId;
-        return;
-    }
-
-    // Show the loading dialog but don't show the filename until we have
-    // verified the token
-    Systray::instance()->createEditFileLocallyLoadingDialog({});
-
-    // We check the input data locally first, without modifying any state or
-    // showing any potentially misleading data to the user
-    if (!isTokenValid(_token)) {
-        qCWarning(lcEditLocallyJob) << "Edit locally request is missing a valid token, will not open file. "
-                                        << "Token received was:" << _token;
-        showError(tr("Invalid token received."), tr("Please try again."));
-        return;
-    }
-
-    if (!isRelPathValid(_relPath)) {
-        qCWarning(lcEditLocallyJob) << "Provided relPath was:" << _relPath << "which is not canonical.";
-        showError(tr("Invalid file path was provided."), tr("Please try again."));
-        return;
-    }
-
-    _accountState = AccountManager::instance()->accountFromUserId(_userId);
-
-    if (!_accountState) {
-        qCWarning(lcEditLocallyJob) << "Could not find an account " << _userId << " to edit file " << _relPath << " locally.";
-        showError(tr("Could not find an account for local editing."), tr("Please try again."));
-        return;
-    }
-
-    // We now ask the server to verify the token, before we again modify any
-    // state or look at local files
-    startTokenRemoteCheck();
-}
-
-void EditLocallyJob::startTokenRemoteCheck()
-{
-    if (!_accountState || _relPath.isEmpty() || _token.isEmpty()) {
-        qCWarning(lcEditLocallyJob) << "Could not start token check."
-                                        << "accountState:" << _accountState
-                                        << "relPath:" << _relPath
-                                        << "token:" << _token;
-
-        showError(tr("Could not start editing locally."),
-                  tr("An error occurred trying to verify the request to edit locally."));
-        return;
-    }
-
-    const auto encodedToken = QString::fromUtf8(QUrl::toPercentEncoding(_token)); // Sanitise the token
-    const auto encodedRelPath = QUrl::toPercentEncoding(_relPath); // Sanitise the relPath
-
-    const auto checkTokenJob = new SimpleApiJob(_accountState->account(),
-                                          QStringLiteral("/ocs/v2.php/apps/files/api/v1/openlocaleditor/%1").arg(encodedToken));
-
-    QUrlQuery params;
-    params.addQueryItem(QStringLiteral("path"), prefixSlashToPath(encodedRelPath));
-    checkTokenJob->addQueryParams(params);
-    checkTokenJob->setVerb(SimpleApiJob::Verb::Post);
-    connect(checkTokenJob, &SimpleApiJob::resultReceived, this, &EditLocallyJob::remoteTokenCheckResultReceived);
-
-    checkTokenJob->start();
-}
-
-void EditLocallyJob::remoteTokenCheckResultReceived(const int statusCode)
-{
-    qCInfo(lcEditLocallyJob) << "token check result" << statusCode;
-
-    constexpr auto HTTP_OK_CODE = 200;
-    _tokenVerified = statusCode == HTTP_OK_CODE;
-
-    if (!_tokenVerified) {
-        showError(tr("Could not validate the request to open a file from server."), tr("Please try again."));
-        return;
-    }
-
-    findAfolderAndConstructPaths();
-}
-
-void EditLocallyJob::proceedWithSetup()
-{
-    if (!_tokenVerified) {
-        qCWarning(lcEditLocallyJob) << "Could not proceed with setup as token is not verified.";
-        showError(tr("Could not validate the request to open a file from server."), tr("Please try again."));
+                                    << "relPath:" << _relPath
+                                    << "accountState:" << _accountState;
+        showError(tr("Could not start editing locally."), tr("An error occurred during setup."));
         return;
     }
 
     const auto relPathSplit = _relPath.split(QLatin1Char('/'));
     if (relPathSplit.isEmpty()) {
-        showError(tr("Could not find a file for local editing. Make sure its path is valid and it is synced locally."), _relPath);
+        showError(tr("Could not find a file for local editing. "
+                     "Make sure its path is valid and it is synced locally."), _relPath);
         return;
     }
 
     _fileName = relPathSplit.last();
-    _folderForFile = findFolderForFile(_relPath, _userId);
-
-    if (!_folderForFile) {
-        showError(tr("Could not find a file for local editing. Make sure it is not excluded via selective sync."), _relPath);
-        return;
-    }
-
-    if (!isFileParentItemValid()) {
-        showError(tr("Could not find a file for local editing. Make sure its path is valid and it is synced locally."), _relPath);
-        return;
-    }
-
-    _localFilePath = _folderForFile->path() + _relativePathToRemoteRoot;
-
-    Systray::instance()->destroyEditFileLocallyLoadingDialog();
-    startEditLocally();
+    Systray::instance()->createEditFileLocallyLoadingDialog(_fileName);
+    findAfolderAndConstructPaths();
 }
 
 void EditLocallyJob::findAfolderAndConstructPaths()
 {
-    _folderForFile = findFolderForFile(_relPath, _userId);
+    _folderForFile = findFolderForFile(_relPath, _accountState->account()->userIdAtHostWithPort());
 
     if (!_folderForFile) {
         showError(tr("Could not find a file for local editing. Make sure it is not excluded via selective sync."), _relPath);
@@ -223,6 +125,25 @@ void EditLocallyJob::fetchRemoteFileParentInfo()
     job->start();
 }
 
+void EditLocallyJob::proceedWithSetup()
+{
+    _folderForFile = findFolderForFile(_relPath, _accountState->account()->userIdAtHostWithPort());
+    
+    if (!_folderForFile) {
+        showError(tr("Could not find a file for local editing. Make sure it is not excluded via selective sync."), _relPath);
+        return;
+    }
+
+    if (!isFileParentItemValid()) {
+        showError(tr("Could not find a file for local editing. Make sure its path is valid and it is synced locally."), _relPath);
+        return;
+    }
+
+    _localFilePath = _folderForFile->path() + _relativePathToRemoteRoot;
+
+    startEditLocally();
+}
+
 bool EditLocallyJob::checkIfFileParentSyncIsNeeded()
 {
     if (_relPathParent == QLatin1String("/")) {
@@ -336,43 +257,6 @@ const QString EditLocallyJob::getRelativePathParent() const
     return QStringLiteral("/");
 }
 
-bool EditLocallyJob::isTokenValid(const QString &token)
-{
-    if (token.isEmpty()) {
-        return false;
-    }
-
-    // Token is an alphanumeric string 128 chars long.
-    // Ensure that is what we received and what we are sending to the server.
-    static const QRegularExpression tokenRegex("^[a-zA-Z0-9]{128}$");
-    const auto regexMatch = tokenRegex.match(token);
-
-    return regexMatch.hasMatch();
-}
-
-bool EditLocallyJob::isRelPathValid(const QString &relPath)
-{
-    if (relPath.isEmpty()) {
-        return false;
-    }
-
-    // We want to check that the path is canonical and not relative
-    // (i.e. that it doesn't contain ../../) but we always receive
-    // a relative path, so let's make it absolute by prepending a
-    // slash
-    const auto slashPrefixedPath = prefixSlashToPath(relPath);
-
-    // Let's check that the filepath is canonical, and that the request
-    // contains no funny behaviour regarding paths
-    const auto cleanedPath = QDir::cleanPath(slashPrefixedPath);
-
-    if (cleanedPath != slashPrefixedPath) {
-        return false;
-    }
-
-    return true;
-}
-
 OCC::Folder *EditLocallyJob::findFolderForFile(const QString &relPath, const QString &userId)
 {
     if (relPath.isEmpty()) {
@@ -380,19 +264,22 @@ OCC::Folder *EditLocallyJob::findFolderForFile(const QString &relPath, const QSt
     }
 
     const auto folderMap = FolderMan::instance()->map();
-
     const auto relPathSplit = relPath.split(QLatin1Char('/'));
 
     // a file is on the first level of remote root, so, we just need a proper folder that points to a remote root
     if (relPathSplit.size() == 1) {
-        const auto foundIt = std::find_if(std::begin(folderMap), std::end(folderMap), [&userId](const OCC::Folder *folder) {
-            return folder->remotePath() == QStringLiteral("/") && folder->accountState()->account()->userIdAtHostWithPort() == userId;
+        const auto foundIt = std::find_if(std::begin(folderMap), 
+                                          std::end(folderMap), 
+                                          [&userId](const OCC::Folder *folder) {
+            const auto folderUserId = folder->accountState()->account()->userIdAtHostWithPort();
+            return folder->remotePath() == QStringLiteral("/") && folderUserId == userId;
         });
 
         return foundIt != std::end(folderMap) ? foundIt.value() : nullptr;
     }
 
-    const auto relPathWithSlash = relPath.startsWith(QStringLiteral("/")) ? relPath : QStringLiteral("/") + relPath;
+    const auto relPathWithSlash = 
+        relPath.startsWith(QStringLiteral("/")) ? relPath : QStringLiteral("/") + relPath;
 
     for (const auto &folder : folderMap) {
         // make sure we properly handle folders with non-root(nested) remote paths
@@ -420,42 +307,11 @@ OCC::Folder *EditLocallyJob::findFolderForFile(const QString &relPath, const QSt
 
 void EditLocallyJob::showError(const QString &message, const QString &informativeText)
 {
-    Systray::instance()->destroyEditFileLocallyLoadingDialog();
-    showErrorNotification(message, informativeText);
-    // to make sure the error is not missed, show a message box in addition
-    showErrorMessageBox(message, informativeText);
+    Systray::instance()->destroyEditFileLocallyLoadingDialog();  
+    EditLocallyManager::showError(message, informativeText);
     Q_EMIT error(message, informativeText);
 }
 
-void EditLocallyJob::showErrorNotification(const QString &message, const QString &informativeText) const
-{
-    if (!_accountState || !_accountState->account()) {
-        return;
-    }
-
-    const auto folderMap = FolderMan::instance()->map();
-    const auto foundFolder = std::find_if(folderMap.cbegin(), folderMap.cend(), [this](const auto &folder) {
-        return _accountState->account()->davUrl() == folder->remoteUrl();
-    });
-
-    if (foundFolder != folderMap.cend()) {
-        emit (*foundFolder)->syncEngine().addErrorToGui(SyncFileItem::SoftError, message, informativeText, OCC::ErrorCategory::GenericError);
-    }
-}
-
-void EditLocallyJob::showErrorMessageBox(const QString &message, const QString &informativeText) const
-{
-    const auto messageBox = new QMessageBox;
-    messageBox->setAttribute(Qt::WA_DeleteOnClose);
-    messageBox->setText(message);
-    messageBox->setInformativeText(informativeText);
-    messageBox->setIcon(QMessageBox::Warning);
-    messageBox->addButton(QMessageBox::StandardButton::Ok);
-    messageBox->show();
-    messageBox->activateWindow();
-    messageBox->raise();
-}
-
 void EditLocallyJob::startEditLocally()
 {
     if (_fileName.isEmpty() || _localFilePath.isEmpty() || !_folderForFile) {
@@ -468,8 +324,6 @@ void EditLocallyJob::startEditLocally()
         return;
     }
 
-    Systray::instance()->createEditFileLocallyLoadingDialog(_fileName);
-
     if (_folderForFile->isSyncRunning()) {
         // in case sync is already running - terminate it and start a new one
         _syncTerminatedConnection = connect(_folderForFile, &Folder::syncFinished, this, [this]() {
@@ -586,7 +440,7 @@ void EditLocallyJob::openFile()
     // In case the VFS mode is enabled and a file is not yet hydrated, we must call QDesktopServices::openUrl
     // from a separate thread, or, there will be a freeze. To avoid searching for a specific folder and checking
     // if the VFS is enabled - we just always call it from a separate thread.
-    QtConcurrent::run([localFilePathUrl, this]() {
+    auto futureResult = QtConcurrent::run([localFilePathUrl, this]() {
         if (!QDesktopServices::openUrl(localFilePathUrl)) {
             emit callShowError(tr("Could not open %1").arg(_fileName), tr("Please try again."));
         }
@@ -613,11 +467,11 @@ void EditLocallyJob::processLocalItem()
     if (rec.isDirectory() || !_accountState->account()->capabilities().filesLockAvailable()) {
         openFile();
     } else {
-        lockFile();
+        lockFile(rec._etag);
     }
 }
 
-void EditLocallyJob::lockFile()
+void EditLocallyJob::lockFile(const QString &etag)
 {
     Q_ASSERT(_accountState);
     Q_ASSERT(_accountState->account());
@@ -652,6 +506,7 @@ void EditLocallyJob::lockFile()
     _folderForFile->accountState()->account()->setLockFileState(_relPath,
                                                                 _folderForFile->remotePathTrailingSlash(),
                                                                 _folderForFile->path(),
+                                                                etag,
                                                                 _folderForFile->journalDb(),
                                                                 SyncFileItem::LockStatus::LockedItem,
                                                                 SyncFileItem::LockOwnerType::TokenLock);
@@ -659,7 +514,7 @@ void EditLocallyJob::lockFile()
 
 void EditLocallyJob::disconnectFolderSignals()
 {
-    for (const auto &connection : qAsConst(_folderConnections)) {
+    for (const auto &connection : std::as_const(_folderConnections)) {
         disconnect(connection);
     }
 }
