@@ -308,6 +308,7 @@ void ShareModel::updateData()
     _placeholderLinkShare.reset(new Share(_accountState->account(),
                                           placeholderLinkShareId,
                                           _accountState->account()->id(),
+                                          _accountState->account()->id(),
                                           _accountState->account()->davDisplayName(),
                                           _sharePath,
                                           Share::TypePlaceholderLink));
@@ -315,6 +316,7 @@ void ShareModel::updateData()
     _internalLinkShare.reset(new Share(_accountState->account(),
                                        internalLinkShareId,
                                        _accountState->account()->id(),
+                                       _accountState->account()->id(),
                                        _accountState->account()->davDisplayName(),
                                        _sharePath,
                                        Share::TypeInternalLink));
@@ -322,6 +324,7 @@ void ShareModel::updateData()
     _secureFileDropPlaceholderLinkShare.reset(new Share(_accountState->account(),
                                                         secureFileDropPlaceholderLinkShareId,
                                                         _accountState->account()->id(),
+                                                        _accountState->account()->id(),
                                                         _accountState->account()->davDisplayName(),
                                                         _sharePath,
                                                         Share::TypeSecureFileDropPlaceholderLink));
@@ -497,7 +500,7 @@ void ShareModel::slotSharesFetched(const QList<SharePtr> &shares)
     for (const auto &share : shares) {
         if (share.isNull() ||
             share->account().isNull() ||
-            share->getUidOwner() != share->account()->davUser()) {
+            share->getUidFileOwner() != share->account()->davUser()) {
             continue;
         }
 
