@@ -28,7 +28,8 @@ OcsShareeJob::OcsShareeJob(AccountPtr account)
 void OcsShareeJob::getSharees(const QString &search,
     const QString &itemType,
     int page,
-    int perPage)
+    int perPage,
+    bool lookup)
 {
     setVerb("GET");
 
@@ -36,6 +37,7 @@ void OcsShareeJob::getSharees(const QString &search,
     addParam(QString::fromLatin1("itemType"), itemType);
     addParam(QString::fromLatin1("page"), QString::number(page));
     addParam(QString::fromLatin1("perPage"), QString::number(perPage));
+    addParam(QString::fromLatin1("lookup"), QVariant(lookup).toString());
 
     start();
 }
