@@ -146,7 +146,7 @@ void Account::setDavUser(const QString &newDavUser)
 
     _davUser = newDavUser;
 
-    emit wantsAccountSaved(this);
+    emit wantsAccountSaved(sharedFromThis());
     emit prettyNameChanged();
 }
 
@@ -332,7 +332,7 @@ void Account::trySetupPushNotifications()
 
             connect(_pushNotifications, &PushNotifications::ready, this, [this]() {
                 _pushNotificationsReconnectTimer.stop();
-                emit pushNotificationsReady(this);
+                emit pushNotificationsReady(sharedFromThis());
             });
 
             const auto disablePushNotifications = [this]() {
@@ -341,7 +341,7 @@ void Account::trySetupPushNotifications()
                     return;
                 }
                 if (!_pushNotifications->isReady()) {
-                    emit pushNotificationsDisabled(this);
+                    emit pushNotificationsDisabled(sharedFromThis());
                 }
                 if (!_pushNotificationsReconnectTimer.isActive()) {
                     _pushNotificationsReconnectTimer.start();
@@ -609,7 +609,7 @@ void Account::slotHandleSslErrors(QNetworkReply *reply, QList<QSslError> errors)
         if (!approvedCerts.isEmpty()) {
             QSslConfiguration::defaultConfiguration().addCaCertificates(approvedCerts);
             addApprovedCerts(approvedCerts);
-            emit wantsAccountSaved(this);
+            emit wantsAccountSaved(sharedFromThis());
 
             // all ssl certs are known and accepted. We can ignore the problems right away.
             qCInfo(lcAccount) << out << "Certs are known and trusted! This is not an actual error.";
@@ -737,7 +737,7 @@ bool Account::shouldSkipE2eeMetadataChecksumValidation() const
 void Account::resetShouldSkipE2eeMetadataChecksumValidation()
 {
     _skipE2eeMetadataChecksumValidation = false;
-    emit wantsAccountSaved(this);
+    emit wantsAccountSaved(sharedFromThis());
 }
 
 int Account::serverVersionInt() const
@@ -796,6 +796,11 @@ int Account::checksumRecalculateServerVersionMinSupportedMajor() const
     return checksumRecalculateRequestServerVersionMinSupportedMajor;
 }
 
+bool Account::bulkUploadNeedsLegacyChecksumHeader() const
+{
+    return serverVersionInt() < makeServerVersion(32, 0, 0);
+}
+
 void Account::setServerVersion(const QString &version)
 {
     if (version == _serverVersion) {
@@ -804,7 +809,7 @@ void Account::setServerVersion(const QString &version)
 
     auto oldServerVersion = _serverVersion;
     _serverVersion = version;
-    emit serverVersionChanged(this, oldServerVersion, version);
+    emit serverVersionChanged(sharedFromThis(), oldServerVersion, version);
 }
 
 void Account::writeAppPasswordOnce(QString appPassword){
@@ -1117,7 +1122,7 @@ void Account::setEncryptionCertificateFingerprint(const QByteArray &fingerprint)
     _encryptionCertificateFingerprint = fingerprint;
     _e2e.usbTokenInformation()->setSha256Fingerprint(fingerprint);
     Q_EMIT encryptionCertificateFingerprintChanged();
-    Q_EMIT wantsAccountSaved(this);
+    Q_EMIT wantsAccountSaved(sharedFromThis());
 }
 
 void Account::setAskUserForMnemonic(const bool ask)
