@@ -64,11 +64,14 @@ public:
     [[nodiscard]] bool shareResharing() const;
     [[nodiscard]] int shareDefaultPermissions() const;
     [[nodiscard]] bool chunkingNg() const;
+    [[nodiscard]] qint64 maxChunkSize() const;
+    [[nodiscard]] int maxConcurrentChunkUploads() const;
     [[nodiscard]] bool bulkUpload() const;
     [[nodiscard]] bool filesLockAvailable() const;
     [[nodiscard]] bool filesLockTypeAvailable() const;
     [[nodiscard]] bool userStatus() const;
     [[nodiscard]] bool userStatusSupportsEmoji() const;
+    [[nodiscard]] bool ncAssistantEnabled() const;
     [[nodiscard]] QColor serverColor() const;
     [[nodiscard]] QColor serverTextColor() const;
 
@@ -165,6 +168,11 @@ public:
      */
     [[nodiscard]] QStringList blacklistedFiles() const;
 
+    [[nodiscard]] QStringList forbiddenFilenameCharacters() const;
+    [[nodiscard]] QStringList forbiddenFilenameBasenames() const;
+    [[nodiscard]] QStringList forbiddenFilenameExtensions() const;
+    [[nodiscard]] QStringList forbiddenFilenames() const;
+
     /**
      * Whether conflict files should remain local (default) or should be uploaded.
      */
@@ -172,6 +180,9 @@ public:
 
     [[nodiscard]] bool groupFoldersAvailable() const;
 
+    [[nodiscard]] bool serverHasValidSubscription() const;
+    [[nodiscard]] QString desktopEnterpriseChannel() const;
+
     // Direct Editing
     void addDirectEditor(DirectEditor* directEditor);
     DirectEditor* getDirectEditorForMimetype(const QMimeType &mimeType);
