@@ -20,18 +20,30 @@
 #include "common/syncjournaldb.h"
 
 Q_LOGGING_CATEGORY(lcSignPublicKeyApiJob, "nextcloud.sync.networkjob.sendcsr", QtInfoMsg)
+Q_LOGGING_CATEGORY(lcStorePublicKeyApiJob, "nextcloud.sync.networkjob.storepublickey", QtInfoMsg)
 Q_LOGGING_CATEGORY(lcStorePrivateKeyApiJob, "nextcloud.sync.networkjob.storeprivatekey", QtInfoMsg)
 Q_LOGGING_CATEGORY(lcCseJob, "nextcloud.sync.networkjob.clientsideencrypt", QtInfoMsg)
 
+namespace
+{
+constexpr auto e2eeSignatureHeaderName = "X-NC-E2EE-SIGNATURE";
+}
+
 namespace OCC {
 
 GetMetadataApiJob::GetMetadataApiJob(const AccountPtr& account,
                                     const QByteArray& fileId,
                                     QObject* parent)
-: AbstractNetworkJob(account, e2eeBaseUrl() + QStringLiteral("meta-data/") + fileId, parent), _fileId(fileId)
+    : AbstractNetworkJob(account, e2eeBaseUrl(account) + QStringLiteral("meta-data/") + fileId, parent)
+    , _fileId(fileId)
 {
 }
 
+const QByteArray &GetMetadataApiJob::signature() const
+{
+    return _signature;
+}
+
 void GetMetadataApiJob::start()
 {
     QNetworkRequest req;
@@ -54,6 +66,9 @@ bool GetMetadataApiJob::finished()
         emit error(_fileId, retCode);
         return true;
     }
+    if (_account->capabilities().clientSideEncryptionVersion() >= 2.0) {
+        _signature = reply()->rawHeader(e2eeSignatureHeaderName);
+    }
     QJsonParseError error{};
     const auto replyData = reply()->readAll();
     auto json = QJsonDocument::fromJson(replyData, &error);
@@ -63,10 +78,16 @@ bool GetMetadataApiJob::finished()
 }
 
 StoreMetaDataApiJob::StoreMetaDataApiJob(const AccountPtr& account,
-                                                 const QByteArray& fileId,
-                                                 const QByteArray& b64Metadata,
-                                                 QObject* parent)
-: AbstractNetworkJob(account, e2eeBaseUrl() + QStringLiteral("meta-data/") + fileId, parent), _fileId(fileId), _b64Metadata(b64Metadata)
+                                         const QByteArray& fileId,
+                                         const QByteArray &token,
+                                         const QByteArray& b64Metadata,
+                                         const QByteArray &signature,
+                                         QObject* parent)
+    : AbstractNetworkJob(account, e2eeBaseUrl(account) + QStringLiteral("meta-data/") + fileId, parent),
+    _fileId(fileId),
+    _token(token),
+    _b64Metadata(b64Metadata),
+    _signature(signature)
 {
 }
 
@@ -75,8 +96,20 @@ void StoreMetaDataApiJob::start()
     QNetworkRequest req;
     req.setRawHeader("OCS-APIREQUEST", "true");
     req.setHeader(QNetworkRequest::ContentTypeHeader, QByteArrayLiteral("application/x-www-form-urlencoded"));
+    if (_account->capabilities().clientSideEncryptionVersion() >= 2.0) {
+        if (!_signature.isEmpty()) {
+            req.setRawHeader(e2eeSignatureHeaderName, _signature);
+        } else {
+            qCWarning(lcCseJob()) << "empty signature for" << _fileId;
+        }
+    }
     QUrlQuery query;
     query.addQueryItem(QLatin1String("format"), QLatin1String("json"));
+    if (_account->capabilities().clientSideEncryptionVersion() < 2.0) {
+        query.addQueryItem(QStringLiteral("e2e-token"), _token);
+    } else {
+        req.setRawHeader(QByteArrayLiteral("e2e-token"), _token);
+    }
     QUrl url = Utility::concatUrlPath(account()->url(), path());
     url.setQuery(query);
 
@@ -91,14 +124,16 @@ void StoreMetaDataApiJob::start()
 
 bool StoreMetaDataApiJob::finished()
 {
-    int retCode = reply()->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
-		if (retCode != 200) {
-			qCInfo(lcCseJob()) << "error sending the metadata" << path() << errorString() << retCode;
-			emit error(_fileId, retCode);
-		}
+    const auto retCode = reply()->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
+    if (retCode != 200) {
+        qCInfo(lcCseJob()) << "error sending the metadata" << path() << errorString() << retCode;
+        emit error(_fileId, retCode);
+        return false;
+    }
+
+    qCInfo(lcCseJob()) << "Metadata submitted to the server successfully";
+    emit success(_fileId);
 
-		qCInfo(lcCseJob()) << "Metadata submitted to the server successfully";
-		emit success(_fileId);
     return true;
 }
 
@@ -106,11 +141,13 @@ UpdateMetadataApiJob::UpdateMetadataApiJob(const AccountPtr& account,
                                                  const QByteArray& fileId,
                                                  const QByteArray& b64Metadata,
                                                  const QByteArray& token,
+                                                 const QByteArray& signature,
                                                  QObject* parent)
-: AbstractNetworkJob(account, e2eeBaseUrl() + QStringLiteral("meta-data/") + fileId, parent)
+: AbstractNetworkJob(account, e2eeBaseUrl(account) + QStringLiteral("meta-data/") + fileId, parent)
 , _fileId(fileId),
 _b64Metadata(b64Metadata),
-_token(token)
+_token(token),
+_signature(signature)
 {
 }
 
@@ -120,16 +157,26 @@ void UpdateMetadataApiJob::start()
     req.setRawHeader("OCS-APIREQUEST", "true");
     req.setHeader(QNetworkRequest::ContentTypeHeader, QByteArrayLiteral("application/x-www-form-urlencoded"));
 
+    if (_account->capabilities().clientSideEncryptionVersion() >= 2.0) {
+        if (!_signature.isEmpty()) {
+            req.setRawHeader(e2eeSignatureHeaderName, _signature);
+        }
+    }
+
     QUrlQuery urlQuery;
     urlQuery.addQueryItem(QStringLiteral("format"), QStringLiteral("json"));
-    urlQuery.addQueryItem(QStringLiteral("e2e-token"), _token);
+
+    if (_account->capabilities().clientSideEncryptionVersion() < 2.0) {
+        urlQuery.addQueryItem(QStringLiteral("e2e-token"), _token);
+    } else {
+        req.setRawHeader(QByteArrayLiteral("e2e-token"), _token);
+    }
 
     QUrl url = Utility::concatUrlPath(account()->url(), path());
     url.setQuery(urlQuery);
 
     QUrlQuery params;
     params.addQueryItem("metaData",QUrl::toPercentEncoding(_b64Metadata));
-    params.addQueryItem("e2e-token", _token);
 
     QByteArray data = params.query().toLocal8Bit();
     auto buffer = new QBuffer(this);
@@ -146,6 +193,7 @@ bool UpdateMetadataApiJob::finished()
 		if (retCode != 200) {
 			qCInfo(lcCseJob()) << "error updating the metadata" << path() << errorString() << retCode;
 			emit error(_fileId, retCode);
+            return false;
 		}
 
 		qCInfo(lcCseJob()) << "Metadata submitted to the server successfully";
@@ -158,7 +206,7 @@ UnlockEncryptFolderApiJob::UnlockEncryptFolderApiJob(const AccountPtr& account,
                                                  const QByteArray& token,
                                                  SyncJournalDb *journalDb,
                                                  QObject* parent)
-    : AbstractNetworkJob(account, e2eeBaseUrl() + QStringLiteral("lock/") + fileId, parent)
+    : AbstractNetworkJob(account, e2eeBaseUrl(account) + QStringLiteral("lock/") + fileId, parent)
     , _fileId(fileId)
     , _token(token)
     , _journalDb(journalDb)
@@ -172,6 +220,13 @@ void UnlockEncryptFolderApiJob::start()
     req.setRawHeader("e2e-token", _token);
 
     QUrl url = Utility::concatUrlPath(account()->url(), path());
+
+    if (shouldRollbackMetadataChanges()) {
+        QUrlQuery query(url);
+        query.addQueryItem(QLatin1String("abort"), QLatin1String("true"));
+        url.setQuery(query);
+    }
+
     sendRequest("DELETE", url, req);
 
     AbstractNetworkJob::start();
@@ -180,6 +235,16 @@ void UnlockEncryptFolderApiJob::start()
     qCInfo(lcCseJob()) << "unlock folder started for:" << path() << " for fileId: " << _fileId;
 }
 
+void UnlockEncryptFolderApiJob::setShouldRollbackMetadataChanges(bool shouldRollbackMetadataChanges)
+{
+    _shouldRollbackMetadataChanges = shouldRollbackMetadataChanges;
+}
+
+[[nodiscard]] bool UnlockEncryptFolderApiJob::shouldRollbackMetadataChanges() const
+{
+    return _shouldRollbackMetadataChanges;
+}
+
 bool UnlockEncryptFolderApiJob::finished()
 {
     int retCode = reply()->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
@@ -198,15 +263,16 @@ bool UnlockEncryptFolderApiJob::finished()
         emit error(_fileId, retCode, errorString());
         return true;
     }
+
     emit success(_fileId);
     return true;
 }
 
 
-DeleteMetadataApiJob::DeleteMetadataApiJob(const AccountPtr& account,
-                                                  const QByteArray& fileId,
-                                                 QObject* parent)
-: AbstractNetworkJob(account, e2eeBaseUrl() + QStringLiteral("meta-data/") + fileId, parent), _fileId(fileId)
+DeleteMetadataApiJob::DeleteMetadataApiJob(const AccountPtr& account, const QByteArray& fileId, const QByteArray &token, QObject* parent)
+: AbstractNetworkJob(account, e2eeBaseUrl(account) + QStringLiteral("meta-data/") + fileId, parent), 
+_fileId(fileId),
+_token(token)
 {
 }
 
@@ -214,6 +280,7 @@ void DeleteMetadataApiJob::start()
 {
     QNetworkRequest req;
     req.setRawHeader("OCS-APIREQUEST", "true");
+    req.setRawHeader(QByteArrayLiteral("e2e-token"), _token);
 
     QUrl url = Utility::concatUrlPath(account()->url(), path());
     sendRequest("DELETE", url, req);
@@ -237,14 +304,16 @@ bool DeleteMetadataApiJob::finished()
 
 LockEncryptFolderApiJob::LockEncryptFolderApiJob(const AccountPtr &account,
                                                  const QByteArray &fileId,
+                                                 const QByteArray &certificateSha256Fingerprint,
                                                  SyncJournalDb *journalDb,
-                                                 const QSslKey publicKey,
+                                                 const QSslKey &sslkey,
                                                  QObject *parent)
-    : AbstractNetworkJob(account, e2eeBaseUrl() + QStringLiteral("lock/") + fileId, parent)
+    : AbstractNetworkJob(account, e2eeBaseUrl(account) + QStringLiteral("lock/") + fileId, parent)
     , _fileId(fileId)
+    , _certificateSha256Fingerprint(certificateSha256Fingerprint)
     , _journalDb(journalDb)
-    , _publicKey(publicKey)
 {
+    Q_UNUSED(sslkey)
 }
 
 void LockEncryptFolderApiJob::start()
@@ -253,8 +322,13 @@ void LockEncryptFolderApiJob::start()
 
     if (!folderTokenEncrypted.isEmpty()) {
         qCInfo(lcCseJob()) << "lock folder started for:" << path() << " for fileId: " << _fileId << " but we need to first lift the previous lock";
-        const auto folderToken = EncryptionHelper::decryptStringAsymmetric(_account->e2e()->_privateKey, folderTokenEncrypted);
-        const auto unlockJob = new OCC::UnlockEncryptFolderApiJob(_account, _fileId, folderToken, _journalDb, this);
+        const auto folderToken = EncryptionHelper::decryptStringAsymmetric(_account->e2e()->getCertificateInformation(), _account->e2e()->paddingMode(), *_account->e2e(), folderTokenEncrypted);
+        if (!folderToken) {
+            qCWarning(lcCseJob()) << "decrypt failed";
+            return;
+        }
+        const auto unlockJob = new OCC::UnlockEncryptFolderApiJob(_account, _fileId, *folderToken, _journalDb, this);
+        unlockJob->setShouldRollbackMetadataChanges(true);
         connect(unlockJob, &UnlockEncryptFolderApiJob::done, this, [this]() {
             this->start();
         });
@@ -264,12 +338,18 @@ void LockEncryptFolderApiJob::start()
 
     QNetworkRequest req;
     req.setRawHeader("OCS-APIREQUEST", "true");
+    if (_account->capabilities().clientSideEncryptionVersion() >= 2.0) {
+        if (_counter > 0) {
+            req.setRawHeader("X-NC-E2EE-COUNTER", QByteArray::number(_counter));
+        }
+    }
     QUrlQuery query;
     query.addQueryItem(QLatin1String("format"), QLatin1String("json"));
     QUrl url = Utility::concatUrlPath(account()->url(), path());
     url.setQuery(query);
 
     qCInfo(lcCseJob()) << "locking the folder with id" << _fileId << "as encrypted";
+
     sendRequest("POST", url, req);
     AbstractNetworkJob::start();
 
@@ -295,9 +375,13 @@ bool LockEncryptFolderApiJob::finished()
 
     qCInfo(lcCseJob()) << "lock folder finished with code" << retCode << " for:" << path() << " for fileId: " << _fileId << " token:" << token;
 
-    if (!_publicKey.isNull()) {
-        const auto folderTokenEncrypted = EncryptionHelper::encryptStringAsymmetric(_publicKey, token);
-        _journalDb->setE2EeLockedFolder(_fileId, folderTokenEncrypted);
+    if (!_account->e2e()->getPublicKey().isNull()) {
+        const auto folderTokenEncrypted = EncryptionHelper::encryptStringAsymmetric(_account->e2e()->getCertificateInformation(), _account->e2e()->paddingMode(), *_account->e2e(), token);
+        if (!folderTokenEncrypted) {
+            qCWarning(lcCseJob()) << "decrypt failed";
+            return false;
+        }
+        _journalDb->setE2EeLockedFolder(_fileId, *folderTokenEncrypted);
     }
 
     //TODO: Parse the token and submit.
@@ -305,8 +389,13 @@ bool LockEncryptFolderApiJob::finished()
     return true;
 }
 
+void LockEncryptFolderApiJob::setCounter(quint64 counter)
+{
+    _counter = counter;
+}
+
 SetEncryptionFlagApiJob::SetEncryptionFlagApiJob(const AccountPtr& account, const QByteArray& fileId, FlagAction flagAction, QObject* parent)
-: AbstractNetworkJob(account, e2eeBaseUrl() + QStringLiteral("encrypted/") + fileId, parent), _fileId(fileId), _flagAction(flagAction)
+: AbstractNetworkJob(account, e2eeBaseUrl(account) + QStringLiteral("encrypted/") + fileId, parent), _fileId(fileId), _flagAction(flagAction)
 {
 }
 
@@ -336,6 +425,45 @@ bool SetEncryptionFlagApiJob::finished()
     return true;
 }
 
+StorePublicKeyApiJob::StorePublicKeyApiJob(const AccountPtr& account, const QString& path, QObject* parent)
+    : AbstractNetworkJob(account, path, parent)
+{
+}
+
+void StorePublicKeyApiJob::setPublicKey(const QByteArray& publicKey)
+{
+    QByteArray data = "publicKey=";
+    data += QUrl::toPercentEncoding(publicKey);
+    _publicKey.setData(data);
+}
+
+void StorePublicKeyApiJob::start()
+{
+    QNetworkRequest req;
+    req.setRawHeader("OCS-APIREQUEST", "true");
+    req.setHeader(QNetworkRequest::ContentTypeHeader, QByteArrayLiteral("application/x-www-form-urlencoded"));
+    QUrlQuery query;
+    query.addQueryItem(QLatin1String("format"), QLatin1String("json"));
+    QUrl url = Utility::concatUrlPath(account()->url(), path());
+    url.setQuery(query);
+
+    qCDebug(lcStorePublicKeyApiJob) << "Sending the public key";
+    sendRequest("PUT", url, req, &_publicKey);
+    AbstractNetworkJob::start();
+}
+
+bool StorePublicKeyApiJob::finished()
+{
+    int retCode = reply()->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
+    if (retCode != 200)
+        qCInfo(lcStorePublicKeyApiJob()) << "Sending public key ended with"  << path() << errorString() << retCode;
+
+    QJsonParseError error{};
+    auto json = QJsonDocument::fromJson(reply()->readAll(), &error);
+    emit jsonReceived(json, reply()->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt());
+    return true;
+}
+
 StorePrivateKeyApiJob::StorePrivateKeyApiJob(const AccountPtr& account, const QString& path, QObject* parent)
 : AbstractNetworkJob(account, path, parent)
 {
@@ -357,7 +485,7 @@ void StorePrivateKeyApiJob::start()
     QUrl url = Utility::concatUrlPath(account()->url(), path());
     url.setQuery(query);
 
-    qCInfo(lcStorePrivateKeyApiJob) << "Sending the private key" << _privKey.data();
+    qCDebug(lcStorePrivateKeyApiJob) << "Sending the private key";
     sendRequest("POST", url, req, &_privKey);
     AbstractNetworkJob::start();
 }
@@ -396,7 +524,7 @@ void SignPublicKeyApiJob::start()
     QUrl url = Utility::concatUrlPath(account()->url(), path());
     url.setQuery(query);
 
-    qCInfo(lcSignPublicKeyApiJob) << "Sending the CSR" << _csr.data();
+    qCDebug(lcSignPublicKeyApiJob) << "Sending the CSR";
     sendRequest("POST", url, req, &_csr);
     AbstractNetworkJob::start();
 }
