@@ -18,18 +18,11 @@
 
 namespace OCC {
 enum class ClientStatusReportingStatus {
-    DownloadError_Cannot_Create_File = 0,
-    DownloadError_Conflict,
-    DownloadError_ConflictCaseClash,
+    DownloadError_ConflictCaseClash = 0,
     DownloadError_ConflictInvalidCharacters,
-    DownloadError_No_Free_Space,
     DownloadError_ServerError,
     DownloadError_Virtual_File_Hydration_Failure,
     E2EeError_GeneralError,
-    UploadError_Conflict,
-    UploadError_ConflictInvalidCharacters,
-    UploadError_No_Free_Space,
-    UploadError_No_Write_Permissions,
     UploadError_ServerError,
     UploadError_Virus_Detected,
     Count,
