@@ -434,7 +434,7 @@ void HttpCredentials::persist()
         // it's just written if it gets passed into the constructor.
         _account->setCredentialSetting(QLatin1String(clientCertBundleC), _clientCertBundle);
     }
-    emit _account->wantsAccountSaved(_account);
+    emit _account->wantsAccountSaved(_account->sharedFromThis());
 
     // write secrets to the keychain
     if (!_clientCertBundle.isEmpty()) {
