@@ -23,9 +23,7 @@
 #include <QBuffer>
 #include <QFile>
 
-#if !defined(Q_OS_MACOS) || __MAC_OS_X_VERSION_MIN_REQUIRED >= MAC_OS_X_VERSION_10_15
 #include <filesystem>
-#endif
 
 namespace OCC {
 class PropagateDownloadEncrypted;
@@ -270,9 +268,7 @@ private:
 
     PropagateDownloadEncrypted *_downloadEncryptedHelper = nullptr;
 
-#if !defined(Q_OS_MACOS) || __MAC_OS_X_VERSION_MIN_REQUIRED >= MAC_OS_X_VERSION_10_15
     std::filesystem::path _parentPath;
-#endif
     bool _needParentFolderRestorePermissions = false;
 };
 }
