@@ -16,12 +16,12 @@
 
 #include <QMap>
 
-#include "abstractpropagateremotedeleteencrypted.h"
+#include "basepropagateremotedeleteencrypted.h"
 #include "syncfileitem.h"
 
 namespace OCC {
 
-class PropagateRemoteDeleteEncryptedRootFolder : public AbstractPropagateRemoteDeleteEncrypted
+class PropagateRemoteDeleteEncryptedRootFolder : public BasePropagateRemoteDeleteEncrypted
 {
     Q_OBJECT
 public:
@@ -30,8 +30,9 @@ public:
     void start() override;
 
 private:
-    void slotFolderUnLockedSuccessfully(const QByteArray &folderId) override;
-    void slotFolderEncryptedMetadataReceived(const QJsonDocument &json, int statusCode) override;
+    void slotFolderUnLockFinished(const QByteArray &folderId, int statusCode) override;
+    void slotFetchMetadataJobFinished(int statusCode, const QString &message) override;
+    void slotUpdateMetadataJobFinished(int statusCode, const QString &message) override;
     void slotDeleteNestedRemoteItemFinished();
 
     void deleteNestedRemoteItem(const QString &filename);
