@@ -46,6 +46,8 @@ public:
     };
     Q_ENUM(Direction)
 
+    using EncryptionStatus = EncryptionStatusEnums::ItemEncryptionStatus;
+
     // Note: the order of these statuses is used for ordering in the SortedActivityListModel
     enum Status { // stored in 4 bits
         NoStatus,
@@ -70,6 +72,11 @@ public:
          */
         FileNameInvalid,
 
+        /**
+         * The filename contains invalid characters and can not be uploaded to the server
+         */
+        FileNameInvalidOnServer,
+
         /**
          * There is a file name clash (e.g. attempting to download test.txt when TEST.TXT already exists
          * on a platform where the filesystem is case-insensitive
@@ -126,7 +133,7 @@ public:
 
     /** Creates a basic SyncFileItem from remote properties
      */
-    [[nodiscard]] static SyncFileItemPtr fromProperties(const QString &filePath, const QMap<QString, QString> &properties);
+    [[nodiscard]] static SyncFileItemPtr fromProperties(const QString &filePath, const QMap<QString, QString> &properties, RemotePermissions::MountedPermissionAlgorithm algorithm);
 
 
     SyncFileItem()
@@ -138,7 +145,6 @@ public:
         , _status(NoStatus)
         , _isRestoration(false)
         , _isSelectiveSync(false)
-        , _isEncrypted(false)
     {
     }
 
@@ -228,6 +234,10 @@ public:
             && !(_instruction == CSYNC_INSTRUCTION_CONFLICT && _status == SyncFileItem::Success);
     }
 
+    [[nodiscard]] bool isEncrypted() const { return _e2eEncryptionStatus != EncryptionStatus::NotEncrypted; }
+
+    void updateLockStateFromDbRecord(const SyncJournalFileRecord &dbRecord);
+
     // Variables useful for everybody
 
     /** The syncfolder-relative filesystem path that the operation is about
@@ -273,10 +283,15 @@ public:
     Status _status BITFIELD(4);
     bool _isRestoration BITFIELD(1); // The original operation was forbidden, and this is a restoration
     bool _isSelectiveSync BITFIELD(1); // The file is removed or ignored because it is in the selective sync list
-    bool _isEncrypted BITFIELD(1); // The file is E2EE or the content of the directory should be E2EE
+    EncryptionStatus _e2eEncryptionStatus = EncryptionStatus::NotEncrypted; // The file is E2EE or the content of the directory should be E2EE
+    EncryptionStatus _e2eEncryptionServerCapability = EncryptionStatus::NotEncrypted;
+    EncryptionStatus _e2eEncryptionStatusRemote = EncryptionStatus::NotEncrypted;
+    QByteArray _e2eCertificateFingerprint;
     quint16 _httpErrorCode = 0;
     RemotePermissions _remotePerm;
     QString _errorString; // Contains a string only in case of error
+    QString _errorExceptionName; // Contains a server exception string only in case of error
+    QString _errorExceptionMessage; // Contains a server exception message string only in case of error
     QByteArray _responseTimeStamp;
     QByteArray _requestId; // X-Request-Id of the failed request
     quint32 _affectedItems = 1; // the number of affected items by the operation on this item.
@@ -312,11 +327,30 @@ public:
     QString _lockEditorApp;
     qint64 _lockTime = 0;
     qint64 _lockTimeout = 0;
+    QString _lockToken;
 
     bool _isShared = false;
     time_t _lastShareStateFetchedTimestamp = 0;
 
     bool _sharedByMe = false;
+
+    bool _isFileDropDetected = false;
+
+    bool _isEncryptedMetadataNeedUpdate = false;
+
+    bool _isAnyInvalidCharChild = false;
+    bool _isAnyCaseClashChild = false;
+
+    bool _isLivePhoto = false;
+    QString _livePhotoFile;
+
+    bool isPermissionsInvalid = false;
+
+    QString _discoveryResult;
+
+    /// if true, requests the file to be permanently deleted instead of moved to the trashbin
+    /// only relevant for when `_instruction` is set to `CSYNC_INSTRUCTION_REMOVE`
+    bool _wantsPermanentDeletion = false;
 };
 
 inline bool operator<(const SyncFileItemPtr &item1, const SyncFileItemPtr &item2)
