@@ -53,12 +53,12 @@ private slots:
 
     void testValidNetrc() {
        NetrcParser parser(testfileC);
-       QEXPECT_FAIL("", "test currently broken, eventually will be fixed", Abort);
        QVERIFY(parser.parse());
-       QCOMPARE(parser.find("foo"), qMakePair(QString("bar"), QString("baz")));
-       QCOMPARE(parser.find("broken"), qMakePair(QString("bar2"), QString()));
-       QCOMPARE(parser.find("funnysplit"), qMakePair(QString("bar3"), QString("baz3")));
-       QCOMPARE(parser.find("frob"), qMakePair(QString("user with spaces"), QString("space pwd")));
+       QCOMPARE(parser.find("foo"), qMakePair(QStringLiteral("bar"), QStringLiteral("baz")));
+       QCOMPARE(parser.find("broken"), qMakePair(QStringLiteral("bar2"), QString()));
+       QCOMPARE(parser.find("funnysplit"), qMakePair(QStringLiteral("bar3"), QStringLiteral("baz3")));
+       QEXPECT_FAIL("", "Current implementation do not support spaces in username or password", Continue);
+       QCOMPARE(parser.find("frob"), qMakePair(QStringLiteral("user with spaces"), QStringLiteral("space pwd")));
     }
 
     void testEmptyNetrc() {
@@ -69,10 +69,9 @@ private slots:
 
     void testValidNetrcWithDefault() {
        NetrcParser parser(testfileWithDefaultC);
-       QEXPECT_FAIL("", "test currently broken, eventually will be fixed", Abort);
        QVERIFY(parser.parse());
-       QCOMPARE(parser.find("foo"), qMakePair(QString("bar"), QString("baz")));
-       QCOMPARE(parser.find("dontknow"), qMakePair(QString("user"), QString("pass")));
+       QCOMPARE(parser.find("foo"), qMakePair(QStringLiteral("bar"), QStringLiteral("baz")));
+       QCOMPARE(parser.find("dontknow"), qMakePair(QStringLiteral("user"), QStringLiteral("pass")));
     }
 
     void testInvalidNetrc() {
