@@ -278,7 +278,7 @@ private slots:
 
         const auto expectedLinkShareExpireDate = QDate::fromString(_testLinkShareDefinition.shareExpiration, helper.expectedDtFormat);
         QCOMPARE(shareIndex.data(ShareModel::ExpireDateEnabledRole).toBool(), expectedLinkShareExpireDate.isValid());
-        QCOMPARE(shareIndex.data(ShareModel::ExpireDateRole).toLongLong(), expectedLinkShareExpireDate.startOfDay(Qt::UTC).toMSecsSinceEpoch());
+        QCOMPARE(shareIndex.data(ShareModel::ExpireDateRole).toLongLong(), expectedLinkShareExpireDate.startOfDay(QTimeZone::utc()).toMSecsSinceEpoch());
 
         const auto iconUrl = shareIndex.data(ShareModel::IconUrlRole).toString();
         QVERIFY(iconUrl.contains("public.svg"));
@@ -321,7 +321,7 @@ private slots:
 
         const auto expectedShareExpireDate = QDate::fromString(_testEmailShareDefinition.shareExpiration, helper.expectedDtFormat);
         QCOMPARE(shareIndex.data(ShareModel::ExpireDateEnabledRole).toBool(), expectedShareExpireDate.isValid());
-        QCOMPARE(shareIndex.data(ShareModel::ExpireDateRole).toLongLong(), expectedShareExpireDate.startOfDay(Qt::UTC).toMSecsSinceEpoch());
+        QCOMPARE(shareIndex.data(ShareModel::ExpireDateRole).toLongLong(), expectedShareExpireDate.startOfDay(QTimeZone::utc()).toMSecsSinceEpoch());
 
         const auto iconUrl = shareIndex.data(ShareModel::IconUrlRole).toString();
         QVERIFY(iconUrl.contains("email.svg"));
@@ -364,14 +364,14 @@ private slots:
 
         const auto expectedShareExpireDate = QDate::fromString(_testUserShareDefinition.shareExpiration, helper.expectedDtFormat);
         QCOMPARE(shareIndex.data(ShareModel::ExpireDateEnabledRole).toBool(), expectedShareExpireDate.isValid());
-        QCOMPARE(shareIndex.data(ShareModel::ExpireDateRole).toLongLong(), expectedShareExpireDate.startOfDay(Qt::UTC).toMSecsSinceEpoch());
+        QCOMPARE(shareIndex.data(ShareModel::ExpireDateRole).toLongLong(), expectedShareExpireDate.startOfDay(QTimeZone::utc()).toMSecsSinceEpoch());
 
         const auto iconUrl = shareIndex.data(ShareModel::IconUrlRole).toString();
         QVERIFY(iconUrl.contains("user.svg"));
 
         // Check correct user avatar
         const auto avatarUrl = shareIndex.data(ShareModel::AvatarUrlRole).toString();
-        const auto relativeAvatarPath = QString("remote.php/dav/avatars/%1/%2.png").arg(_testUserShareDefinition.shareShareWith, QString::number(64));
+        const auto relativeAvatarPath = QStringLiteral("remote.php/dav/avatars/%1/%2.png").arg(_testUserShareDefinition.shareShareWith, QString::number(64));
         const auto expectedAvatarPath = Utility::concatUrlPath(helper.account->url(), relativeAvatarPath).toString();
         const QString expectedUrl(QStringLiteral("image://tray-image-provider/") + expectedAvatarPath);
         QCOMPARE(avatarUrl, expectedUrl);
@@ -801,14 +801,14 @@ private slots:
         QCOMPARE(shareIndex.data(ShareModel::ExpireDateEnabledRole).toBool(), false);
 
         // Set a new expire date
-        const auto expireDateMsecs = QDate::currentDate().addDays(10).startOfDay(Qt::UTC).toMSecsSinceEpoch();
+        const auto expireDateMsecs = QDate::currentDate().addDays(10).startOfDay(QTimeZone::utc()).toMSecsSinceEpoch();
         model.setShareExpireDate(linkSharePtr, expireDateMsecs);
         QVERIFY(expireDateSet.wait(3000));
         QCOMPARE(shareIndex.data(ShareModel::ExpireDateRole).toLongLong(), expireDateMsecs);
         QCOMPARE(shareIndex.data(ShareModel::ExpireDateEnabledRole).toBool(), true);
 
         // Test the QML-specific slot
-        const QVariant newExpireDateMsecs = QDate::currentDate().addDays(20).startOfDay(Qt::UTC).toMSecsSinceEpoch();
+        const QVariant newExpireDateMsecs = QDate::currentDate().addDays(20).startOfDay(QTimeZone::utc()).toMSecsSinceEpoch();
         model.setShareExpireDateFromQml(QVariant::fromValue(sharePtr), newExpireDateMsecs);
         QVERIFY(expireDateSet.wait(3000));
         QCOMPARE(shareIndex.data(ShareModel::ExpireDateRole).toLongLong(), newExpireDateMsecs);
@@ -820,7 +820,7 @@ private slots:
         helper.resetTestData();
 
         // Test with an existing link share.
-        // This one has a pre-existing password
+        // This one has a pre-existing note
         helper.appendShareReplyData(_testLinkShareDefinition);
         QCOMPARE(helper.shareCount(), 1);
 
@@ -844,7 +844,7 @@ private slots:
         const auto linkSharePtr = sharePtr.dynamicCast<LinkShare>(); // Need to connect to signal
         QSignalSpy noteSet(linkSharePtr.data(), &LinkShare::noteSet);
 
-        model.toggleShareNoteToRecipient(sharePtr, false);
+        model.setShareNote(sharePtr, QStringLiteral(""));
         QVERIFY(noteSet.wait(3000));
         QCOMPARE(shareIndex.data(ShareModel::NoteEnabledRole).toBool(), false);
 
@@ -852,7 +852,7 @@ private slots:
         model.setShareNote(sharePtr, note);
         QVERIFY(noteSet.wait(3000));
         QCOMPARE(shareIndex.data(ShareModel::NoteEnabledRole).toBool(), true);
-        // The model stores the recently set password.
+        // The model stores the recently set note.
         // We want to present the user with it in the UI while the model is alive
         QCOMPARE(shareIndex.data(ShareModel::NoteRole).toString(), note);
     }
